"""Utilities package for the DataDog HealthCheck Deployer."""

from .constants import (
    API_RATE_LIMIT,
    API_RATE_PERIOD,
    CACHE_DIR,
    CACHE_TTL,
    CHECK_TYPE_DNS,
    CHECK_TYPE_HTTP,
    CHECK_TYPE_ICMP,
    CHECK_TYPE_SSL,
    CHECK_TYPE_TCP,
    CONFIG_FILE,
    DEFAULT_ENV,
    DEFAULT_MAX_RETRY_DELAY,
    DEFAULT_RETRY_COUNT,
    DEFAULT_RETRY_DELAY,
    DEFAULT_SITE,
    DEFAULT_TIMEOUT,
    ENV_API_HOST,
    ENV_API_KEY,
    ENV_APP_KEY,
    ENV_ENV,
    ENV_SITE,
    INTERVAL_DEFAULT,
    INTERVAL_MAX,
    INTERVAL_MIN,
    LOCATIONS,
    MONITOR_ALERT,
    MONITOR_NO_DATA,
    MONITOR_OK,
    MONITOR_SKIPPED,
    MONITOR_UNKNOWN,
    MONITOR_WARN,
    REQUIRED_TAGS,
    TAG_CHECK_TYPE,
    TAG_ENV,
    TAG_LOCATION,
    TAG_MONITOR_TYPE,
    TAG_SERVICE,
    TAG_TEAM,
    TEMPLATE_DIR,
    THRESHOLD_RESPONSE_TIME_CRITICAL,
    THRESHOLD_RESPONSE_TIME_WARNING,
    THRESHOLD_SSL_DAYS_CRITICAL,
    THRESHOLD_SSL_DAYS_WARNING,
    TIMEOUT_DNS,
    TIMEOUT_HTTP,
    TIMEOUT_ICMP,
    TIMEOUT_SSL,
    TIMEOUT_TCP,
    VALID_CHECK_TYPES,
    VALID_CRITERIA,
    VALID_HTTP_METHODS,
    VALID_MONITOR_STATES,
    VALID_MONITOR_TYPES,
    VALID_NOTIFY_TYPES,
    VARIABLES_FILE,
    VERSION,
)
from .exceptions import (
    APIError,
    AuthenticationError,
    CheckError,
    ConfigError,
    DashboardError,
    DeployerError,
    LocationError,
    MonitorError,
    RateLimitError,
    RetryError,
    TemplateError,
    ValidationError,
    ValidationWarning,
    VariableError,
)
from .logging import LoggerMixin, get_logger, log_call, log_exception, setup_logging
from .utils import (
    calculate_hash,
    dump_yaml,
    format_timestamp,
    load_yaml,
    make_request,
    merge_dicts,
    parse_duration,
    retry_with_backoff,
    substitute_variables,
)
from .validation import (
    validate_check_type,
    validate_content_match,
    validate_criteria,
    validate_dns_record,
    validate_http_method,
    validate_interval,
    validate_location,
    validate_monitor_config,
    validate_monitor_state,
    validate_monitor_type,
    validate_notification_channel,
    validate_notify_type,
    validate_ssl_certificate,
    validate_tags,
    validate_tcp_connection,
    validate_template,
    validate_thresholds,
    validate_url,
    validate_variables,
)

__all__ = [
    # Constants
    "API_RATE_LIMIT",
    "API_RATE_PERIOD",
    "CACHE_DIR",
    "CACHE_TTL",
    "CHECK_TYPE_DNS",
    "CHECK_TYPE_HTTP",
    "CHECK_TYPE_ICMP",
    "CHECK_TYPE_SSL",
    "CHECK_TYPE_TCP",
    "CONFIG_FILE",
    "DEFAULT_ENV",
    "DEFAULT_MAX_RETRY_DELAY",
    "DEFAULT_RETRY_COUNT",
    "DEFAULT_RETRY_DELAY",
    "DEFAULT_SITE",
    "DEFAULT_TIMEOUT",
    "ENV_API_HOST",
    "ENV_API_KEY",
    "ENV_APP_KEY",
    "ENV_ENV",
    "ENV_SITE",
    "INTERVAL_DEFAULT",
    "INTERVAL_MAX",
    "INTERVAL_MIN",
    "LOCATIONS",
    "MONITOR_ALERT",
    "MONITOR_NO_DATA",
    "MONITOR_OK",
    "MONITOR_SKIPPED",
    "MONITOR_UNKNOWN",
    "MONITOR_WARN",
    "REQUIRED_TAGS",
    "TAG_CHECK_TYPE",
    "TAG_ENV",
    "TAG_LOCATION",
    "TAG_MONITOR_TYPE",
    "TAG_SERVICE",
    "TAG_TEAM",
    "TEMPLATE_DIR",
    "THRESHOLD_RESPONSE_TIME_CRITICAL",
    "THRESHOLD_RESPONSE_TIME_WARNING",
    "THRESHOLD_SSL_DAYS_CRITICAL",
    "THRESHOLD_SSL_DAYS_WARNING",
    "TIMEOUT_DNS",
    "TIMEOUT_HTTP",
    "TIMEOUT_ICMP",
    "TIMEOUT_SSL",
    "TIMEOUT_TCP",
    "VALID_CHECK_TYPES",
    "VALID_CRITERIA",
    "VALID_HTTP_METHODS",
    "VALID_MONITOR_STATES",
    "VALID_MONITOR_TYPES",
    "VALID_NOTIFY_TYPES",
    "VARIABLES_FILE",
    "VERSION",
    # Exceptions
    "APIError",
    "AuthenticationError",
    "CheckError",
    "ConfigError",
    "DashboardError",
    "DeployerError",
    "LocationError",
    "MonitorError",
    "RateLimitError",
    "RetryError",
    "TemplateError",
    "ValidationError",
    "ValidationWarning",
    "VariableError",
    # Logging
    "setup_logging",
    "get_logger",
    "LoggerMixin",
    "log_call",
    "log_exception",
    # Utils
    "load_yaml",
    "dump_yaml",
    "merge_dicts",
    "substitute_variables",
    "calculate_hash",
    "retry_with_backoff",
    "format_timestamp",
    "parse_duration",
    "make_request",
    # Validation
    "validate_check_type",
    "validate_http_method",
    "validate_monitor_type",
    "validate_monitor_state",
    "validate_notify_type",
    "validate_criteria",
    "validate_location",
    "validate_tags",
    "validate_interval",
    "validate_url",
    "validate_ssl_certificate",
    "validate_dns_record",
    "validate_tcp_connection",
    "validate_content_match",
    "validate_thresholds",
    "validate_variables",
    "validate_template",
    "validate_notification_channel",
    "validate_monitor_config",
]
